@@ -11,10 +11,10 @@ from abc import ABCMeta, abstractmethod
 import aiohttp
 from aiohttp import web
 
-from alicebot.adapter import AbstractAdapter
+from alicebot.adapter import Adapter
 
 
-class PollingAdapter(AbstractAdapter, metaclass=ABCMeta):
+class PollingAdapter(Adapter, metaclass=ABCMeta):
     """
     轮询式适配器示例。
     """
@@ -51,7 +51,7 @@ class HttpClientAdapter(PollingAdapter, metaclass=ABCMeta):
         await self.session.close()
 
 
-class WebSocketClientAdapter(AbstractAdapter, metaclass=ABCMeta):
+class WebSocketClientAdapter(Adapter, metaclass=ABCMeta):
     """
     WebSocket 客户端适配器示例。
     """
@@ -73,7 +73,7 @@ class WebSocketClientAdapter(AbstractAdapter, metaclass=ABCMeta):
         pass
 
 
-class HttpServerAdapter(AbstractAdapter, metaclass=ABCMeta):
+class HttpServerAdapter(Adapter, metaclass=ABCMeta):
     """
     HTTP 服务端适配器示例。
     """
@@ -104,14 +104,14 @@ class HttpServerAdapter(AbstractAdapter, metaclass=ABCMeta):
         pass
 
 
-class WebSocketServerAdapter(AbstractAdapter, metaclass=ABCMeta):
+class WebSocketServerAdapter(Adapter, metaclass=ABCMeta):
     """
     WebSocket 服务端适配器示例。
     """
-    app: web.Application
-    runner: web.AppRunner
-    site: web.TCPSite
-    websocket: web.WebSocketResponse
+    app: web.Application = None
+    runner: web.AppRunner = None
+    site: web.TCPSite = None
+    websocket: web.WebSocketResponse = None
     host: str
     port: int
     url: str
@@ -127,7 +127,12 @@ class WebSocketServerAdapter(AbstractAdapter, metaclass=ABCMeta):
         await self.site.start()
 
     async def shutdown(self):
-        await self.runner.cleanup()
+        if self.websocket is not None:
+            await self.websocket.close()
+        if self.site is not None:
+            await self.site.stop()
+        if self.runner is not None:
+            await self.runner.cleanup()
 
     async def handle_response(self, request: web.Request):
         ws = web.WebSocketResponse()
@@ -136,8 +141,6 @@ class WebSocketServerAdapter(AbstractAdapter, metaclass=ABCMeta):
 
         msg: aiohttp.WSMessage
         async for msg in ws:
-            if self.bot.should_exit:
-                break
             if msg.type == aiohttp.WSMsgType.TEXT:
                 await self.handle_ws_response(msg)
             elif msg.type == aiohttp.WSMsgType.ERROR:
