@@ -29,7 +29,7 @@ class Event(ABC, BaseModel):
     handled: bool = False
     """
     表示事件是否被处理过了，用于适配器处理。
-    注意：请勿手动更改此属性的值。
+    警告：请勿手动更改此属性的值。
     """
 
     def __str__(self) -> str:
@@ -39,5 +39,5 @@ class Event(ABC, BaseModel):
         return self.__str__()
 
     class Config:
-        extra = "allow"
+        extra = 'allow'
         json_encoders = {Message: DataclassEncoder}
